==> wtwco_igloo_cloud_api_client-2.0.0-py3-none-any.whl: wtwco_igloo_cloud_api_client/api/result_table/get_result_table_for_run.py <==
from http import HTTPStatus
from typing import Any, Dict, Optional, Union, cast

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.data_table_include import DataTableInclude
from ...models.response_wrapper import ResponseWrapper
from ...models.table_data_response import TableDataResponse
from ...types import UNSET, Response, Unset


def _get_kwargs(
    project_id: int,
    run_id: int,
    run_result_name: str,
    result_table_name: str,
    *,
    job_id: Union[Unset, int] = UNSET,
    include: Union[Unset, DataTableInclude] = UNSET,
) -> Dict[str, Any]:
    params: Dict[str, Any] = {}

    params["jobId"] = job_id

    json_include: Union[Unset, str] = UNSET
    if not isinstance(include, Unset):
        json_include = include.value

    params["include"] = json_include

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: Dict[str, Any] = {
        "method": "get",
        "url": f"/api/v2/projects/{project_id}/runs/{run_id}/runresults/{run_result_name}/{result_table_name}",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[Any, ResponseWrapper, TableDataResponse]]:
    if response.status_code == HTTPStatus.OK:
        response_200 = TableDataResponse.from_dict(response.json())

        return response_200
    if response.status_code == HTTPStatus.UNAUTHORIZED:
        response_401 = cast(Any, None)
        return response_401
    if response.status_code == HTTPStatus.FORBIDDEN:
        response_403 = cast(Any, None)
        return response_403
    if response.status_code == HTTPStatus.NOT_FOUND:
        response_404 = cast(Any, None)
        return response_404
    if response.status_code == HTTPStatus.NOT_ACCEPTABLE:
        response_406 = ResponseWrapper.from_dict(response.json())

        return response_406
    if response.status_code == HTTPStatus.CONFLICT:
        response_409 = cast(Any, None)
        return response_409
    if response.status_code == HTTPStatus.GONE:
        response_410 = cast(Any, None)
        return response_410
    if response.status_code == HTTPStatus.UNSUPPORTED_MEDIA_TYPE:
        response_415 = ResponseWrapper.from_dict(response.json())

        return response_415
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[Any, ResponseWrapper, TableDataResponse]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_id: int,
    run_id: int,
    run_result_name: str,
    result_table_name: str,
    *,
    client: Union[AuthenticatedClient, Client],
    job_id: Union[Unset, int] = UNSET,
    include: Union[Unset, DataTableInclude] = UNSET,
) -> Response[Union[Any, ResponseWrapper, TableDataResponse]]:
    """Gets the data in a result table.

    Args:
        project_id (int):
        run_id (int):
        run_result_name (str):
        result_table_name (str):
        job_id (Union[Unset, int]):
        include (Union[Unset, DataTableInclude]): Used in a GetDataTableForRun query to indicate
            whether you are interested in the table definition, the table data or both of these
            things.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, ResponseWrapper, TableDataResponse]]
    """

    kwargs = _get_kwargs(
        project_id=project_id,
        run_id=run_id,
        run_result_name=run_result_name,
        result_table_name=result_table_name,
        job_id=job_id,
        include=include,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    project_id: int,
    run_id: int,
    run_result_name: str,
    result_table_name: str,
    *,
    client: Union[AuthenticatedClient, Client],
    job_id: Union[Unset, int] = UNSET,
    include: Union[Unset, DataTableInclude] = UNSET,
) -> Optional[Union[Any, ResponseWrapper, TableDataResponse]]:
    """Gets the data in a result table.

    Args:
        project_id (int):
        run_id (int):
        run_result_name (str):
        result_table_name (str):
        job_id (Union[Unset, int]):
        include (Union[Unset, DataTableInclude]): Used in a GetDataTableForRun query to indicate
            whether you are interested in the table definition, the table data or both of these
            things.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, ResponseWrapper, TableDataResponse]
    """

    return sync_detailed(
        project_id=project_id,
        run_id=run_id,
        run_result_name=run_result_name,
        result_table_name=result_table_name,
        client=client,
        job_id=job_id,
        include=include,
    ).parsed


async def asyncio_detailed(
    project_id: int,
    run_id: int,
    run_result_name: str,
    result_table_name: str,
    *,
    client: Union[AuthenticatedClient, Client],
    job_id: Union[Unset, int] = UNSET,
    include: Union[Unset, DataTableInclude] = UNSET,
) -> Response[Union[Any, ResponseWrapper, TableDataResponse]]:
    """Gets the data in a result table.

    Args:
        project_id (int):
        run_id (int):
        run_result_name (str):
        result_table_name (str):
        job_id (Union[Unset, int]):
        include (Union[Unset, DataTableInclude]): Used in a GetDataTableForRun query to indicate
            whether you are interested in the table definition, the table data or both of these
            things.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, ResponseWrapper, TableDataResponse]]
    """

    kwargs = _get_kwargs(
        project_id=project_id,
        run_id=run_id,
        run_result_name=run_result_name,
        result_table_name=result_table_name,
        job_id=job_id,
        include=include,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    project_id: int,
    run_id: int,
    run_result_name: str,
    result_table_name: str,
    *,
    client: Union[AuthenticatedClient, Client],
    job_id: Union[Unset, int] = UNSET,
    include: Union[Unset, DataTableInclude] = UNSET,
) -> Optional[Union[Any, ResponseWrapper, TableDataResponse]]:
    """Gets the data in a result table.

    Args:
        project_id (int):
        run_id (int):
        run_result_name (str):
        result_table_name (str):
        job_id (Union[Unset, int]):
        include (Union[Unset, DataTableInclude]): Used in a GetDataTableForRun query to indicate
            whether you are interested in the table definition, the table data or both of these
            things.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, ResponseWrapper, TableDataResponse]
    """

    return (
        await asyncio_detailed(
            project_id=project_id,
            run_id=run_id,
            run_result_name=run_result_name,
            result_table_name=result_table_name,
            client=client,
            job_id=job_id,
            include=include,
        )
    ).parsed

==> wtwco_igloo_cloud_api_client-3.0.1-py3-none-any.whl: wtwco_igloo_cloud_api_client/api/result_table/get_result_table_for_run.py <==
from http import HTTPStatus
from typing import Any, Optional, Union, cast

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.data_table_include import DataTableInclude
from ...models.response_wrapper import ResponseWrapper
from ...models.table_data_response import TableDataResponse
from ...types import UNSET, Response, Unset


def _get_kwargs(
    workspace_id: int,
    project_id: int,
    run_id: int,
    run_result_name: str,
    result_table_name: str,
    *,
    job_id: Union[Unset, int] = UNSET,
    include: Union[Unset, DataTableInclude] = UNSET,
) -> dict[str, Any]:
    params: dict[str, Any] = {}

    params["job-id"] = job_id

    json_include: Union[Unset, str] = UNSET
    if not isinstance(include, Unset):
        json_include = include.value

    params["include"] = json_include

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": f"/api/v3/workspaces/{workspace_id}/projects/{project_id}/runs/{run_id}/run-results/{run_result_name}/tables/{result_table_name}",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[Any, ResponseWrapper, TableDataResponse]]:
    if response.status_code == 406:
        response_406 = ResponseWrapper.from_dict(response.json())

        return response_406
    if response.status_code == 415:
        response_415 = ResponseWrapper.from_dict(response.json())

        return response_415
    if response.status_code == 401:
        response_401 = cast(Any, None)
        return response_401
    if response.status_code == 200:
        response_200 = TableDataResponse.from_dict(response.json())

        return response_200
    if response.status_code == 404:
        response_404 = ResponseWrapper.from_dict(response.json())
        return response_404
    if response.status_code == 409:
        response_409 = ResponseWrapper.from_dict(response.json())
        return response_409
    if response.status_code == 410:
        response_410 = ResponseWrapper.from_dict(response.json())
        return response_410
    if response.status_code == 403:
        response_403 = cast(Any, None)
        return response_403
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[Any, ResponseWrapper, TableDataResponse]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    workspace_id: int,
    project_id: int,
    run_id: int,
    run_result_name: str,
    result_table_name: str,
    *,
    client: Union[AuthenticatedClient, Client],
    job_id: Union[Unset, int] = UNSET,
    include: Union[Unset, DataTableInclude] = UNSET,
) -> Response[Union[Any, ResponseWrapper, TableDataResponse]]:
    """Gets the data in a result table.

    Args:
        workspace_id (int):
        project_id (int):
        run_id (int):
        run_result_name (str):
        result_table_name (str):
        job_id (Union[Unset, int]):
        include (Union[Unset, DataTableInclude]): Used in a GetDataTableForRun query to indicate
            whether you are interested in the table definition, the table data or both of these
            things.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, ResponseWrapper, TableDataResponse]]
    """

    kwargs = _get_kwargs(
        workspace_id=workspace_id,
        project_id=project_id,
        run_id=run_id,
        run_result_name=run_result_name,
        result_table_name=result_table_name,
        job_id=job_id,
        include=include,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    workspace_id: int,
    project_id: int,
    run_id: int,
    run_result_name: str,
    result_table_name: str,
    *,
    client: Union[AuthenticatedClient, Client],
    job_id: Union[Unset, int] = UNSET,
    include: Union[Unset, DataTableInclude] = UNSET,
) -> Optional[Union[Any, ResponseWrapper, TableDataResponse]]:
    """Gets the data in a result table.

    Args:
        workspace_id (int):
        project_id (int):
        run_id (int):
        run_result_name (str):
        result_table_name (str):
        job_id (Union[Unset, int]):
        include (Union[Unset, DataTableInclude]): Used in a GetDataTableForRun query to indicate
            whether you are interested in the table definition, the table data or both of these
            things.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, ResponseWrapper, TableDataResponse]
    """

    return sync_detailed(
        workspace_id=workspace_id,
        project_id=project_id,
        run_id=run_id,
        run_result_name=run_result_name,
        result_table_name=result_table_name,
        client=client,
        job_id=job_id,
        include=include,
    ).parsed


async def asyncio_detailed(
    workspace_id: int,
    project_id: int,
    run_id: int,
    run_result_name: str,
    result_table_name: str,
    *,
    client: Union[AuthenticatedClient, Client],
    job_id: Union[Unset, int] = UNSET,
    include: Union[Unset, DataTableInclude] = UNSET,
) -> Response[Union[Any, ResponseWrapper, TableDataResponse]]:
    """Gets the data in a result table.

    Args:
        workspace_id (int):
        project_id (int):
        run_id (int):
        run_result_name (str):
        result_table_name (str):
        job_id (Union[Unset, int]):
        include (Union[Unset, DataTableInclude]): Used in a GetDataTableForRun query to indicate
            whether you are interested in the table definition, the table data or both of these
            things.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, ResponseWrapper, TableDataResponse]]
    """

    kwargs = _get_kwargs(
        workspace_id=workspace_id,
        project_id=project_id,
        run_id=run_id,
        run_result_name=run_result_name,
        result_table_name=result_table_name,
        job_id=job_id,
        include=include,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    workspace_id: int,
    project_id: int,
    run_id: int,
    run_result_name: str,
    result_table_name: str,
    *,
    client: Union[AuthenticatedClient, Client],
    job_id: Union[Unset, int] = UNSET,
    include: Union[Unset, DataTableInclude] = UNSET,
) -> Optional[Union[Any, ResponseWrapper, TableDataResponse]]:
    """Gets the data in a result table.

    Args:
        workspace_id (int):
        project_id (int):
        run_id (int):
        run_result_name (str):
        result_table_name (str):
        job_id (Union[Unset, int]):
        include (Union[Unset, DataTableInclude]): Used in a GetDataTableForRun query to indicate
            whether you are interested in the table definition, the table data or both of these
            things.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, ResponseWrapper, TableDataResponse]
    """

    return (
        await asyncio_detailed(
            workspace_id=workspace_id,
            project_id=project_id,
            run_id=run_id,
            run_result_name=run_result_name,
            result_table_name=result_table_name,
            client=client,
            job_id=job_id,
            include=include,
        )
    ).parsed
